@@ -10,25 +10,22 @@ import models
 
 @transaction.commit_manually
 def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
-    u"""
+    '''
     Заполнение справочника КЛАДР
-
-    :param region_only: первые два символа региона, для ограничения загрузки
-        только этого региона
-    :param str dbf_path: путь к папке с файлами загрузки
-    :param bool clear_before: флаг очистки таблиц КЛАДР перед загрузкой
-    :param bool update: флаг обновления существующих записей
-    """
+    region_only - первые два символа региона,
+    для ограничения загрузки только этого региона
+    '''
     COMMIT_PER = 5000
 
-    def make_obj(model, code):
-        result = model(code=code)
-        if update:
+    if update:
+        def make_obj(model, code):
             try:
-                result = model.objects.get(code=code)
-            except model.DoesNotExist:
-                pass
-        return result
+                return model.objects.get(code=code)
+            except:
+                return model(code=code)
+    else:
+        def make_obj(model, code):
+            return model(code=code)
 
     def fill_record(result_list, rec, type):
         temp_dict = {}
@@ -47,13 +44,13 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
         if type == 'subject':
             code = temp_dict['code'][:2]
             temp_dict['level'] = 0
-        elif type == 'region':
+        if type == 'region':
             code = temp_dict['code'][:5]
             temp_dict['level'] = 1
-        elif type == 'city':
+        if type == 'city':
             code = temp_dict['code'][:8]
             temp_dict['level'] = 2
-        elif type == 'place':
+        if type == 'place':
             code = temp_dict['code'][:11]
             temp_dict['level'] = 3
 
@@ -114,8 +111,8 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
 
     list_count = len(sub_list)
     transaction_commit_counter = 0
-
-    for i, sub_value in enumerate(sub_list.itervalues(), start=1):
+    i = 1
+    for sub_value in sub_list.itervalues():
         new_kladr_geo_sub = make_obj(
             models.KladrGeo, sub_value['code'])
         new_kladr_geo_sub.parent = None
@@ -136,8 +133,10 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
         if transaction_commit_counter % COMMIT_PER == 0:
             transaction.commit()
         if i % 1000 == 1:
-            print ''.join(
-                (str(i), '/', str(list_count), ' ', new_kladr_geo_sub.name))
+            print (
+                str(i) + '/' + str(list_count) + ' ' + new_kladr_geo_sub.name
+            )
+        i = i + 1
 
     i = 1
     list_count = len(region_list)
@@ -165,11 +164,11 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
             if transaction_commit_counter % COMMIT_PER == 0:
                 transaction.commit()
             if i % 1000 == 1:
-                print ''.join((
-                    ' ' * 5, str(i), '/', str(list_count), ' ',
-                    new_kladr_geo_region.name
-                ))
-            i += 1
+                print (
+                    ' '*5 + str(i) + '/' + str(list_count) +
+                    ' ' + new_kladr_geo_region.name
+                )
+            i = i + 1
 
     i = 1
     list_count = len(city_list)
@@ -200,11 +199,11 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
                 if transaction_commit_counter % COMMIT_PER == 0:
                     transaction.commit()
                 if i % 1000 == 1:
-                    print ''.join((
-                        ' ' * 8, str(i), '/', str(list_count), ' ',
-                        new_kladr_geo_city.name
-                    ))
-                i += 1
+                    print (
+                        ' '*8 + str(i) + '/' + str(list_count) +
+                        ' ' + new_kladr_geo_city.name
+                    )
+                i = i + 1
 
         elif code[2:] != '000':
             # ищем родителя в регионах
@@ -230,11 +229,11 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
                 if transaction_commit_counter % COMMIT_PER == 0:
                     transaction.commit()
                 if i % 1000 == 1:
-                    print ''.join((
-                        ' ' * 8, str(i), '/', str(list_count), ' ',
-                        new_kladr_geo_city.name
-                    ))
-                i += 1
+                    print (
+                        ' '*8 + str(i) + '/' + str(list_count) +
+                        ' ' + new_kladr_geo_city.name
+                    )
+                i = i + 1
 
     i = 1
     list_count = len(geo_places_list)
@@ -270,11 +269,11 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
                     if transaction_commit_counter % COMMIT_PER == 0:
                         transaction.commit()
                     if i % 1000 == 1:
-                        print ''.join((
-                            ' ' * 13, str(i), '/', str(list_count), ' ',
-                            new_kladr_geo_place.name
-                        ))
-                    i += 1
+                        print (
+                            ' '*13 + str(i) + '/' + str(list_count) +
+                            ' ' + new_kladr_geo_place.name
+                        )
+                    i = i + 1
 
         elif (code[5:8] == '000') and not (code[2:5] == '000'):
             #поиск родителя в районах
@@ -304,11 +303,11 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
                     if transaction_commit_counter % COMMIT_PER == 0:
                         transaction.commit()
                     if i % 1000 == 1:
-                        print ''.join((
-                            ' ' * 13, str(i), '/', str(list_count), ' ',
-                            new_kladr_geo_place.name
-                        ))
-                    i += 1
+                        print (
+                            ' '*13 + str(i) + '/' + str(list_count) +
+                            ' ' + new_kladr_geo_place.name
+                        )
+                    i = i + 1
 
         elif (code[5:8] == '000') and (code[2:5] == '000'):
             #поиск родителя в субъектах
@@ -339,11 +338,11 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
                     if transaction_commit_counter % COMMIT_PER == 0:
                         transaction.commit()
                     if i % 1000 == 1:
-                        print ''.join((
-                            ' ' * 13, str(i), '/', str(list_count), ' ',
-                            new_kladr_geo_place.name
-                        ))
-                    i += 1
+                        print (
+                            ' '*13 + str(i) + '/' + str(list_count) +
+                            ' ' + new_kladr_geo_place.name
+                        )
+                    i = i + 1
 
     i = 1
     #list_count = len(street_list)
@@ -375,18 +374,18 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
                     if transaction_commit_counter % COMMIT_PER == 0:
                         transaction.commit()
                     if i % 1000 == 1:
-                        print ''.join((
-                            ' ' * 20, str(i), '/', str(list_count), ' ',
-                            street_sub.name
-                        ))
-                    i += 1
+                        print (
+                            ' '*20 + str(i) + '/' + str(list_count) +
+                            ' ' + street_sub.name
+                        )
+                    i = i + 1
 
             elif (code[8:11] == '000') and (code[5:8] != '000'):
                 # поиск родителя в городах
                 code = code[:8]
                 try:
                     parent_id = city_list[code]
-                except KeyError:
+                except:
                     error_code_streets_list.append(code)
                 else:
                     street_city = make_obj(
@@ -402,11 +401,11 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
                     if transaction_commit_counter % COMMIT_PER == 0:
                         transaction.commit()
                     if i % 1000 == 1:
-                        print ''.join((
-                            ' ' * 20, str(i), '/', str(list_count), ' ',
-                            street_city.name
-                        ))
-                    i += 1
+                        print (
+                            ' '*20 + str(i) + '/' + str(list_count) +
+                            ' ' + street_city.name
+                        )
+                    i = i + 1
 
             else:
                 # поиск родителя в селах\деревнях
@@ -429,11 +428,11 @@ def fill_kladr(region_only=None, dbf_path='', clear_before=True, update=False):
                     if transaction_commit_counter % COMMIT_PER == 0:
                         transaction.commit()
                     if i % 1000 == 1:
-                        print ''.join((
-                            ' ' * 20, str(i), '/', str(list_count), ' ',
-                            street_place.name
-                        ))
-                    i += 1
+                        print (
+                            ' '*20 + str(i) + '/' + str(list_count) +
+                            ' ' + street_place.name
+                        )
+                    i = i + 1
 
     transaction.commit()
     print (u'Загрузка КЛАДР в систему завершена')
